netapp_ontap.models.ad_domain_svm API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ad_domain_svm`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AdDomainSvmSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AdDomainSvm object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `default_site: str GET POST PATCH`

    The default site used by LIFs that do not have a site membership.

  `fqdn: str GET POST`

    The fully qualified domain name of the Windows Active Directory to which this CIFS server belongs. A CIFS server appears as a member of Windows server object in the Active Directory store.

    Example: example.com

  `organizational_unit: str GET POST`

    Specifies the organizational unit within the Active Directory domain to associate with the CIFS server.

  `password: str POST`

    The account password used to add this CIFS server to the Active Directory. This is not audited. Valid in POST only.

  `user: str POST`

    The user account used to add this CIFS server to the Active Directory. Valid in POST only.